#include <ctime>

#include <stdlib.h>
#include <fstream>
#include <libIRDB-core.hpp>
#include <libgen.h>
#include <stars.h>

using namespace std;
using namespace libIRDB;

#include "stars_irdb.hpp"

#define SMP_DEBUG_DELAY 0   // for setting an early breakpoint


void usage(char* name)
{
	cerr<<"Usage: "<<name<<" <variant_id>\n"; 
}

int main(int argc, char **argv)
{
        if(argc != 2)
        {
                usage(argv[0]);
                exit(1);
        }

		// For debugging, we can add a delay loop so we have time to attach gdb to the
		// running process and set a breakpoint.
#if SMP_DEBUG_DELAY
		time_t start;
		time_t current;

		time(&start);
		cerr << "delay for 15 seconds." << endl;
		do {
			time(&current);
		} while (difftime(current, start) < 15.0);
#endif
		
		string programName(argv[0]);
        int variantID = atoi(argv[1]);

        VariantID_t *pidp=NULL;

        /* setup the interface to the sql server */
        pqxxDB_t pqxx_interface;
        BaseObj_t::SetInterface(&pqxx_interface);

        pidp=new VariantID_t(variantID);
        assert(pidp->IsRegistered()==true);

	cout<<argv[0]<<" started\n";

        for(set<File_t*>::iterator it=pidp->GetFiles().begin();
            it!=pidp->GetFiles().end();
                ++it)
        {
                File_t* this_file = *it;
                try
                {
                	FileIR_t *firp = new FileIR_t(*pidp, this_file);

			cout<<"Transforming "<<this_file->GetURL()<<endl;

                	assert(firp && pidp);

			int success=true;

			STARS::IRDB_Interface_t stars_analysis_engine(pqxx_interface);

			// run stars
			stars_analysis_engine.do_STARS(firp);

                        delete firp;
                }
                catch (DatabaseError_t pnide)
                {
                        cerr << programName << ": Unexpected database error: " << pnide << "file url: " << this_file->GetURL() << endl;
                }
                catch (...)
                {
                        cerr << programName << ": Unexpected error file url: " << this_file->GetURL() << endl;
                }
        } // end file iterator


        return 0;
}

